=======
Physics
=======

SWAN physics commands

Generation
~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.GEN1
   rompy_swan.components.physics.GEN2
   rompy_swan.components.physics.GEN3

Swell dissipation
~~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.NEGATINP
   rompy_swan.components.physics.SSWELL_ARDHUIN
   rompy_swan.components.physics.SSWELL_ZIEGER
   rompy_swan.components.physics.SSWELL_ROGERS

Whitecapping
~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.WCAPPING_KOMEN
   rompy_swan.components.physics.WCAPPING_AB

Quadruplet interactions
~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.QUADRUPL

Wave breaking
~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.BREAKING_CONSTANT
   rompy_swan.components.physics.BREAKING_BKD

Bottom friction
~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.FRICTION_JONSWAP
   rompy_swan.components.physics.FRICTION_COLLINS
   rompy_swan.components.physics.FRICTION_MADSEN
   rompy_swan.components.physics.FRICTION_RIPPLES

Wave triads
~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.TRIAD
   rompy_swan.components.physics.TRIAD_DCTA
   rompy_swan.components.physics.TRIAD_LTA
   rompy_swan.components.physics.TRIAD_SPB

Vegetaion dumping
~~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.VEGETATION

Mud dumping
~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.MUD

Sea ice dissipation
~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.SICE
   rompy_swan.components.physics.SICE_R19
   rompy_swan.components.physics.SICE_D15
   rompy_swan.components.physics.SICE_M18
   rompy_swan.components.physics.SICE_R21B

Turbulent viscosity
~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.TURBULENCE

Bragg scattering
~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.BRAGG
   rompy_swan.components.physics.BRAGG_FT
   rompy_swan.components.physics.BRAGG_FILE

Limiter
~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.LIMITER

Obstacle
~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.OBSTACLE
   rompy_swan.components.physics.OBSTACLE_FIG
   rompy_swan.components.physics.OBSTACLES

Wave setup
~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.SETUP

Wave diffraction
~~~~~~~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.DIFFRACTION

Surfbeat
~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.SURFBEAT

Scattering
~~~~~~~~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.SCAT

Off
~~~

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.physics.OFF
   rompy_swan.components.physics.OFFS
